@@ -3,10 +3,11 @@ import datetime as dt_module
 import re
 import sys
 from collections import namedtuple
-from datetime import date, datetime
+from datetime import date, datetime, timedelta
 from numpy import (
     array, concatenate, cos, float_, int64, isnan, isinf, linspace,
     nan, ndarray, nonzero, pi, rollaxis, searchsorted, sin, where, zeros_like,
+
 )
 from time import strftime, struct_time
 from ._compatibility import interp
@@ -23,6 +24,7 @@ from .nutationlib import (
 )
 from .precessionlib import compute_precession
 
+DAY_US = 86400000000.0
 GREGORIAN_START = 2299161
 GREGORIAN_START_ENGLAND = 2361222
 _OLD_PYTHON = sys.version_info < (2, 7)
@@ -49,7 +51,7 @@ if hasattr(dt_module, 'timezone'):
 else:
     class UTC(dt_module.tzinfo):
         'UTC'
-        zero = dt_module.timedelta(0)
+        zero = timedelta(0)
         def utcoffset(self, dt):
             return self.zero
         def tzname(self, dt):
@@ -883,13 +885,35 @@ class Time(object):
     # Various dunders.
 
     def __eq__(self, other_time):
-        return self.__sub__(other_time) == 0.0
+        if isinstance(other_time, Time):
+            return self.__sub__(other_time) == 0.0
+        return False
+
+    def __add__(self, other_time):
+        if isinstance(other_time, timedelta):
+            w = other_time.days
+            f = other_time.seconds / DAY_S + other_time.microseconds / DAY_US
+        elif isinstance(other_time, (int, float)):
+            w, f = divmod(other_time, 1.0)
+        else:
+            return NotImplemented
+
+        return self.ts.tt_jd(self.whole + w, self.tt_fraction + f)
 
     def __sub__(self, other_time):
-        if not isinstance(other_time, Time):
+        if isinstance(other_time, Time):
+            return self.whole - other_time.whole + (
+                self.tt_fraction - other_time.tt_fraction
+            )
+        elif isinstance(other_time, timedelta):
+            w = other_time.days
+            f = other_time.seconds / DAY_S + other_time.microseconds / DAY_US
+        elif isinstance(other_time, (int, float)):
+            w, f = divmod(other_time, 1.0)
+        else:
             return NotImplemented
-        return ((self.whole - other_time.whole)
-                + (self.tt_fraction - other_time.tt_fraction))
+
+        return self.ts.tt_jd(self.whole - w, self.tt_fraction - f)
 
     def __hash__(self):
         # Someone wanted to use Time objects with functools.lru_cache so
@@ -898,6 +922,13 @@ class Time(object):
         # all round to the same floating point TT.
         return hash(self.tt)
 
+    # Interoperability.
+
+    def to_astropy(self):
+        """Return an AstroPy object representing this time."""
+        from astropy.time import Time
+        return Time(self.whole, self.tt_fraction, format='jd', scale='tt')
+
     # Deprecated attributes that were once used internally, consuming
     # memory with matrices that are never used again by Skyfield once
     # t.M has been computed.
@@ -1030,6 +1061,15 @@ delta_t_parabola_morrison_stephenson_2004 = Splines(
     [1820.0, 1920.0, 0.0, 32.0, 0.0, -20.0])
 
 def build_delta_t(delta_t_recent):
+    """Return a function t→∆T, given recent real-world observations of ∆T.
+
+    When asked for ∆T outside the range of the `delta_t_recent` table,
+    Skyfield uses the splines for 720 BC – AD 2015 computed by Morrison,
+    Stephenson, Hohenkerk, and Zawilski.  For dates that fall outside of
+    the spines, we use the long-term parabola of Stephenson, Morrison,
+    and Hohenkerk.
+
+    """
     parabola = delta_t_parabola_stephenson_morrison_hohenkerk_2016
     s15_table = load_bundled_npy('delta_t.npz')['Table-S15.2020.txt']
     table_tt, table_delta_t = delta_t_recent
